Themes in Pyrone

# Custom styles in Pyrone

Pyrone now supports custom styles. You should create your own CSS-file using default style file blog.css as a template. Just save that file edit and upload to internal storage. Then choose your style on the settings page.

There are some moments you should know about style. First it MUST have appropriate header, typically it looks like this:

    /* pyrone-theme-css */
    /* pyrone-theme-data:title-en: Style name in english*/
    /* pyrone-theme-data:title-ru: Название стиля in russian*/

First line MUST be `/* pyrone-theme-css */`, without it Pyrone won't recognize that CSS-file as a proper theme file. Also file may contain other metadata, they look like `/* pyrone-theme-data:title-en: Default style (template)*/`, this will be used as style name on settings page (for every supported language, if you don't include these line regular style filename will be used).

Second important moment — when uploading CSS-file you must set File access type to the value leave processing to web browser, without it file won't be recognized as a theme file. And of course file must have extension .css.

You can use images, just upload them as regular files to the storage and use absolute path like `/files/f/image.png` in CSS-code:

    .account-twitter {
        background-repeat: no-repeat;
        background-position: top left;
        background-image: url(/files/f/twitter-icon.png);
        padding-left: 17px;
    }